from django.conf import settings
from authX.authX_constants import AUTHX_CONSTANT_CONFIGS

AUTHX_SETTINGS =  {
    'AUTHX_USER_MODEL': getattr(settings,'AUTHX_USER_MODEL', AUTHX_CONSTANT_CONFIGS['AUTHX_USER_MODEL']),
    'AUTHX_LOGIN_URL' : getattr(settings,'AUTHX_LOGIN_URL', AUTHX_CONSTANT_CONFIGS['AUTHX_LOGIN_URL']),
    'AUTHX_LOGOUT_URL': getattr(settings,'AUTHX_LOGOUT_URL', AUTHX_CONSTANT_CONFIGS['AUTHX_LOGOUT_URL']),
    'AUTHX_REGISTER_URL': getattr(settings,'AUTHX_REGISTER_URL', AUTHX_CONSTANT_CONFIGS['AUTHX_REGISTER_URL']),
    'AUTHX_DASHBOARD_URL': getattr(settings,'AUTHX_DASHBOARD_URL', AUTHX_CONSTANT_CONFIGS['AUTHX_DASHBOARD_URL']),
}